Preferences/__init__.py

changeset 3207
6cf664694e3c
parent 3200
83bde5e6f146
child 3341
7c015811fc4d
--- a/Preferences/__init__.py	Wed Jan 15 19:05:51 2014 +0100
+++ b/Preferences/__init__.py	Wed Jan 15 19:16:06 2014 +0100
@@ -977,8 +977,8 @@
         "IconEditorState": QByteArray(),
     }
     
-    # defaults for py3flakes
-    py3flakesDefaults = {
+    # defaults for pyflakes
+    pyflakesDefaults = {
         "IncludeInSyntaxCheck": True,
         "IgnoreStarImportWarnings": True,
     }
@@ -2706,7 +2706,7 @@
 
 def getFlakes(key, prefClass=Prefs):
     """
     Module function to retrieve the py3flakes related settings.
     
     @param key the key of the value to get
     @param prefClass preferences class used as the storage area
@@ -2714,15 +2714,15 @@
     """
     if key in ["IncludeInSyntaxCheck", "IgnoreStarImportWarnings"]:
         return toBool(prefClass.settings.value("Py3Flakes/" + key,
-                      prefClass.py3flakesDefaults[key]))
+                      prefClass.pyflakesDefaults[key]))
     else:
         return prefClass.settings.value(
-            "Py3Flakes/" + key, prefClass.py3flakesDefaults[key])
+            "Py3Flakes/" + key, prefClass.pyflakesDefaults[key])
     
 
 def setFlakes(key, value, prefClass=Prefs):
     """
     Module function to store the py3flakes related settings.
     
     @param key the key of the setting to be set
     @param value the value to be set
@@ -2706,7 +2706,7 @@
 def getFlakes(key, prefClass=Prefs):
     """
-    Module function to retrieve the py3flakes related settings.
+    Module function to retrieve the pyflakes related settings.
     
     @param key the key of the value to get
@@ -2714,15 +2714,15 @@
 def setFlakes(key, value, prefClass=Prefs):
     """
-    Module function to store the py3flakes related settings.
+    Module function to store the pyflakes related settings.
     
     @param key the key of the setting to be set

eric ide

mercurial